@@ -323,7 +323,9 @@ catalogToDataFrame <- function(x, keys = TRUE, rownames = NULL,
         for (i in seq_along(entry_list)) {
             for (j in names(entry_list[[i]])) {
                 val <- entry_list[[i]][[j]]
-                if (identical(val, list())) {
+                # By checking if identical to unnamed list we replace  JSON `[]` and
+                # `{}` with NAs but not `NULL` so that bad keys still get right error
+                if (identical(unname(val), list())) {
                     val <- NA
                 }
                 out[[j]][i] <- val
