@@ -89,12 +89,17 @@ with_mock_crunch({
     })
 
     test_that("Scripts catalog print method", {
+        # Better error message for problem in R 4.1 and macos-arm64
+        formatted <- formatScriptCatalog(
+            scripts(ds),
+            from = strptime("2020-05-09", "%Y-%m-%d", tz = "UTC"),
+            body_width = 10
+        )
+        expect_equal(formatted$Timestamp, "2 days ago")
+
+        # full test
         expect_identical(
-            formatScriptCatalog(
-                scripts(ds),
-                from = strptime("2020-05-09", "%Y-%m-%d"),
-                body_width = 10
-            ),
+            formatted,
             data.frame(
                 Timestamp = c("2 days ago"),
                 scriptBody = paste0(strtrim(script_text, 7), "..."),
@@ -147,6 +152,7 @@ with_mock_crunch({
         expect_equal(
             failures,
             list(
+                last_attempted_script = "RENAME wrong_var_name TO age;",
                 file = NULL,
                 errors = data.frame(
                     column = NA,
@@ -182,6 +188,9 @@ with_mock_crunch({
         expect_equal(
             failures,
             list(
+                last_attempted_script = paste0(
+                    "RENAME wrong_var_name TO age;\nRENAME wrong_var_name2 TO age;"
+                ),
                 file = NULL,
                 errors = data.frame(
                     column = c(NA, NA),
@@ -198,6 +207,40 @@ with_mock_crunch({
         )
     })
 
+    test_that("Can interpret error from async script failures", {
+        # Override progress with a pre-generated JSON at the url
+        with_mock(
+            `crunch::crPOST` = function(..., progress.handler = NULL) {
+                capture.output(crunch::pollProgress(
+                    "https://app.crunch.io/api/progress-failed-async-script.json",
+                    wait = 0.01,
+                    error_handler = progress.handler
+                ))
+            }, {
+                expect_error(
+                    ds <- runCrunchAutomation(ds, "NOT A COMMAND"),
+                    "Crunch Automation Error"
+                )
+            }
+        )
+
+        expect_message(
+            failures <- showScriptErrors(),
+            "\\(line 1\\) Invalid command: NOT",
+        )
+    })
+
+    test_that("Get message on success when dry_run is TRUE", {
+        with_POST(
+            "", # Don't actually need to load anything, just need no POST error
+            expect_message(
+                runCrunchAutomation(ds, "# no commands", dry_run = TRUE),
+                "Script dry run was successful"
+            )
+        )
+
+    })
+
     test_that("error truncation works", {
         expected <- " - (line 1) Error 1\n - (line 2) Error 2\n - ... (Showing first 2 of 3 errors)"
         attr(expected, "truncated") <- TRUE
