@@ -1,7 +1,7 @@
 context("Shallow copies of variables")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     test_that("copy creates a correct VariableDefinition", {
         expect_is(copy(ds$gender), "VariableDefinition")
         expected <- VariableDefinition(
